# ProbeInterface Library

Library of probes in the **probeinterface** format.


See:

  * GitHub repo: https://github.com/SpikeInterface/probeinterface
  * Documentation: https://probeinterface.readthedocs.io/


The format of probes is JSON-based. See [documentation](https://probeinterface.readthedocs.io/en/main/format_spec.html) for full specifications.


  
